Todo list
=========

Other stuff
-----------
* ☐ Export documentation.
* ☐ Add documentation about development.
* ☐ Easily upload to pypi.
* ☐ Auto report messages to Razor (high scoring ones that are definitely spam)
* ☐ Separate out messages that may be false positives (scores close to
    SpamAssassin thresholds) from the definite spam ones.
* ☐ Add documentation for the crontab usage.
* ☐ Remove the *SpamAssassin* report from a mail when it is in the `ham`
    folder.

Notes
^^^^^

====== ==== ==== =====================
Symbol Dec. Hex  Name
====== ==== ==== =====================
 ☐     9744 2610 BALLOT BOX
 ☑     9745 2611 BALLOT BOX WITH CHECK
 ☒     9746 2612 BALLOT BOX WITH X
====== ==== ==== =====================
